Examples
========

Try out in Binder! |Binder|

.. |Binder| image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/gh/scikit-hep/pyhf/master?filepath=docs%2Fexamples%2Fnotebooks%2Fbinderexample%2FStatisticalAnalysis.ipynb

Notebooks:

.. toctree::
   :maxdepth: 2
   :glob:

   examples/notebooks/*
   examples/notebooks/binderexample/*
